Datasets
========
.. automodapi:: pykeen.datasets

.. automodapi:: pykeen.datasets.base

.. automodapi:: pykeen.datasets.analysis

Inductive Datasets
==================
.. automodapi:: pykeen.datasets.inductive

Entity Alignment
================
.. automodapi:: pykeen.datasets.ea.combination
